<?php
/**
 * ryzen Theme Customizer
 *
 * @package ryzen
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ryzen_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'ryzen_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'ryzen_customize_partial_blogdescription',
			)
		);
		
		// adding copyright section to the customizer
	

		 $wp_customize-> add_section('ryzen_copyright_sec', array(
			'title' => __('Copyright','ryzen'),
			'description' => __('Please, type here your copyright','ryzen')
		));
		$wp_customize-> add_setting('ryzen_copyright_set', array(
			'type' => 'theme_mod',
			'sanitize_callback' => 'esc_attr'
		));
		$wp_customize-> add_control( 'ryzen_ctrl_copyright', array(
			'label' => __('Copyright Information','ryzen'),
			'description' => __('Please, type your copyright here.','ryzen'),
			'section'   => 'ryzen_copyright_sec',
			'settings'   => 'ryzen_copyright_set',
			'type'  => 'text'
		));
	}
}
add_action( 'customize_register', 'ryzen_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function ryzen_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function ryzen_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ryzen_customize_preview_js() {
	wp_enqueue_script( 'ryzen-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), ryzen, true );
}
add_action( 'customize_preview_init', 'ryzen_customize_preview_js' );
